#!/bin/bash

##############################################################################
## INPUT PARAMETERS
## this is a master-worker model.
## therefore, active processors are NUM_RANKS - 1
NUM_RANKS=$1
## trace folder
TRACE=$2
CONFIG=$3
 
 
 
##############################################################################
### SCRIPT CONTROL
 
### string for mode
if [ $TS_SIM_MEM -eq 1 ] ; then
  MODE="mem"
else
  MODE="burst"
fi
### string for num cores
PADCORES=$(printf "%0*d" 6 $TS_SIM_CORES)
### string for temporary/paraver folder
TMP="trace_"${PADCORES}cores_${MODE}
OUTPUT=presim_results_${TS_SIM_CORES}cores_${MODE}.dat
 
mkdir $TMP
 
######################
### COMMAND EXECUTION
#mpirun --mca mpi_warn_on_fork 0 -n ${NUM_RANKS} xterm -e gdb -ex run --args \
#mpirun -n ${NUM_RANKS} xterm -e gdb -ex run --args \

#mpirun --mca mpi_warn_on_fork 0 -n ${NUM_RANKS} \
mpirun -n ${NUM_RANKS} --report-bindings --output-filename log_presimulation_${TS_SIM_CORES}cores_rank \
      tasksim_presim \
        -d ${TRACE} \
        -o ${OUTPUT} \
        -c ${CONFIG} \
        -t ${TMP}
 
 
##############
## The output is sorted.
## It is not mandatory.
sort ${OUTPUT}      >   ${OUTPUT}.temp
mv   ${OUTPUT}.temp     ${OUTPUT}
 


### THIS MUST ADDRESS SPECIFIC CORE!

#### Once the presimulation has finished... we can replace 
####  the integration folder parameters with the generated 
####  information.
sed -i 's|^PRESIM=.*|PRESIM=../A1_PRESIM/'$OUTPUT'|g' ../A2_INTEGRATION_PRESIM/03_DimemasTS_sim_presim_${PADCORES}.bash
sed -i 's|^TMP=.*|TMP=../A1_PRESIM/'$TMP'|g'          ../A2_INTEGRATION_PRESIM/03_DimemasTS_sim_presim_${PADCORES}.bash


